Package: consensusOV
Type: Package
Title: Gene expression-based subtype classification for high-grade
        serous ovarian cancer
Version: 1.35.0
Date: 2024-02-05
Authors@R: c(
  person('Gregory', 'Chen', 'M', role=c('aut')),
  person('Lavanya', 'Kannan', role=c('aut')),
  person('Ludwig', 'Geistlinger', role=c('aut')),
  person('Victor', 'Kofia', role=c('aut')),
  person('Levi', 'Waldron', role=c('aut')),
  person('Christopher', 'Eeles', email='christopher.eeles@uhnresearch.ca', role=c('ctb')),
  person('Benjamin', 'Haibe-Kains', email='benjamin.haibe.kains@utoronto.ca', role=c('aut', 'cre'))
  )
Maintainer: Benjamin Haibe-Kains <benjamin.haibe.kains@utoronto.ca>
Description: This package implements four major subtype classifiers for
    high-grade serous (HGS) ovarian cancer as described by Helland
    et al. (PLoS One, 2011), Bentink et al. (PLoS One, 2012),
    Verhaak et al. (J Clin Invest, 2013), and Konecny et al. (J
    Natl Cancer Inst, 2014). In addition, the package implements a
    consensus classifier, which consolidates and improves on the
    robustness of the proposed subtype classifiers, thereby
    providing reliable stratification of patients with HGS ovarian
    tumors of clearly defined subtype.
License: Artistic-2.0
Depends: R (>= 3.6)
Imports: Biobase, GSVA (>= 1.50.0), gdata, genefu, limma, matrixStats,
        randomForest, stats, utils, methods, BiocParallel
URL: http://www.pmgenomics.ca/bhklab/software/consensusOV
Suggests: BiocStyle, ggplot2, knitr, rmarkdown, magick
VignetteBuilder: knitr
Encoding: UTF-8
RoxygenNote: 7.3.1
LazyData: true
biocViews: Classification, Clustering, DifferentialExpression,
        GeneExpression, Microarray, Transcriptomics
BugReports: https://github.com/bhklab/consensusOV/issues
git_url: https://git.bioconductor.org/packages/consensusOV
git_branch: devel
git_last_commit: fff0f7a
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-04-29
NeedsCompilation: no
Packaged: 2026-04-29 21:06:34 UTC; biocbuild
Author: Gregory M Chen [aut],
  Lavanya Kannan [aut],
  Ludwig Geistlinger [aut],
  Victor Kofia [aut],
  Levi Waldron [aut],
  Christopher Eeles [ctb],
  Benjamin Haibe-Kains [aut, cre]
