#' Sample ExpressionSet from MetaGxOvarian
#'
#' A Biobase::ExpressionSet from package MetaGxOvarian for the 
#' dataset GSE14764
#'
#' @format A Biobase::ExpressionSet object
#' @source \url{http://biorxiv.org/content/biorxiv/early/2016/05/12/052910.full.pdf}
"GSE14764.eset"
